@@ -104,9 +104,19 @@ def main():
             # task_obj.wrap_up()
     except requests.exceptions.SSLError:
         print("\nSSL error. Are you connected to the Internet and the VPN?")
+    except requests.exceptions.ConnectionError as connection_error:
+        print(
+            f"\nConnection Error when connecting to {connection_error.request.url}. "
+            "Are you connectet to the Internet/VPN? Do you need to update DNS settings?"
+        )
+        sys.exit(1)
+    except FileNotFoundError as fnf_error:
+        print(f"\n{fnf_error.strerror}: {fnf_error.filename}")
+        sys.exit(1)
     except Exception as ee:
         logging.exception("Unhandled exception")
-        raise TransformationProcessError("", "unhandled exception", "") from ee
+        print(f"\n{ee}")
+        sys.exit(1)
 
 
 def inheritors(base_class):
