@@ -27,7 +27,7 @@ class CoursesMapper(MappingFileMapperBase):
         library_configuration: LibraryConfiguration,
         task_configuration,
     ):
-        self.folio_client = folio_client
+        self.folio_client: FolioClient = folio_client
         self.user_cache: dict = {}
         self.notes_mapper: NotesMapper = NotesMapper(
             library_configuration,
@@ -47,7 +47,6 @@ class CoursesMapper(MappingFileMapperBase):
             library_configuration,
         )
         self.course_map = course_map
-        self.use_map = True
         if terms_map:
             self.terms_map = RefDataMapping(
                 self.folio_client,
@@ -144,10 +143,6 @@ class CoursesMapper(MappingFileMapperBase):
     def get_prop(self, legacy_item, folio_prop_name, index_or_id):
         value_tuple = (legacy_item, folio_prop_name, index_or_id)
 
-        # Legacy contstruct
-        if not self.use_map:
-            return legacy_item[folio_prop_name]
-
         legacy_item_keys = self.mapped_from_legacy_data.get(folio_prop_name, [])
 
         # IF there is a value mapped, return that one
@@ -183,19 +178,18 @@ class CoursesMapper(MappingFileMapperBase):
             )
             return ""
 
-    @staticmethod
-    def get_composite_course_schema() -> Dict[str, Any]:
+    def get_composite_course_schema(self) -> Dict[str, Any]:
         return {
             "properties": {
-                "course": FolioClient.get_latest_from_github(
+                "course": self.folio_client.get_from_github(
                     "folio-org", "mod-courses", "/ramls/course.json"
                 ),
-                "courselisting": FolioClient.get_latest_from_github(
+                "courselisting": self.folio_client.get_from_github(
                     "folio-org", "mod-courses", "/ramls/courselisting.json"
                 ),
                 "instructors": {
                     "type": "array",
-                    "items": FolioClient.get_latest_from_github(
+                    "items": self.folio_client.get_from_github(
                         "folio-org", "mod-courses", "/ramls/instructor.json"
                     ),
                 },
