@@ -48,7 +48,6 @@ class MappingFileMapperBase(MapperBase):
         self.unique_record_ids: Set[str] = set()
 
         self.total_records = 0
-        self.use_map = True  # Legacy
         self.record_map = record_map
         self.ref_data_dicts: Dict = {}
         self.empty_vals = empty_vals
@@ -182,42 +181,49 @@ class MappingFileMapperBase(MapperBase):
             if (k["legacy_field"].strip() not in empty_vals)
         ]
 
-    def instantiate_record(self, legacy_object: dict, index_or_id, object_type: FOLIONamespaces):
-
+    def instantiate_record(
+        self,
+        legacy_object: dict,
+        index_or_id,
+        object_type: FOLIONamespaces,
+        accept_duplicate_ids: bool = False,
+    ):
         if self.ignore_legacy_identifier:
             return ({}, str(uuid.uuid4()))
 
-        if legacy_id := " ".join(
-            legacy_object.get(li, "") for li in self.legacy_id_property_names
-        ).strip():
-            generated_id = str(
-                FolioUUID(
-                    self.folio_client.okapi_url,
-                    object_type,
-                    legacy_id,
-                )
-            )
-            if generated_id in self.unique_record_ids:
-                raise TransformationRecordFailedError(
-                    index_or_id,
-                    "Legacy id already generated.",
-                    f"UUID: {generated_id}, seed: {legacy_id}",
-                )
-            self.unique_record_ids.add(generated_id)
-            return (
-                {
-                    "id": generated_id,
-                    "metadata": self.folio_client.get_metadata_construct(),
-                    "type": "object",
-                },
-                legacy_id,
-            )
-        else:
+        if not (
+            legacy_id := " ".join(
+                legacy_object.get(li, "") for li in self.legacy_id_property_names
+            ).strip()
+        ):
             raise TransformationRecordFailedError(
                 index_or_id,
                 "Could not get a value from legacy object from the property "
                 f"{self.legacy_id_property_names}. Check mapping and data",
             )
+        generated_id = str(
+            FolioUUID(
+                self.folio_client.okapi_url,
+                object_type,
+                legacy_id,
+            )
+        )
+        if generated_id in self.unique_record_ids and not accept_duplicate_ids:
+            raise TransformationRecordFailedError(
+                index_or_id,
+                "Legacy id already generated.",
+                f"UUID: {generated_id}, seed: {legacy_id}",
+            )
+        else:
+            self.unique_record_ids.add(generated_id)
+        return (
+            {
+                "id": generated_id,
+                "metadata": self.folio_client.get_metadata_construct(),
+                "type": "object",
+            },
+            legacy_id,
+        )
 
     def get_statistical_codes(self, legacy_item: dict, folio_prop_name: str, index_or_id):
         if self.statistical_codes_mapping:
@@ -239,10 +245,15 @@ class MappingFileMapperBase(MapperBase):
         raise NotImplementedError("This method needs to be implemented in a implementing class")
 
     def do_map(
-        self, legacy_object, index_or_id: str, object_type: FOLIONamespaces
+        self,
+        legacy_object,
+        index_or_id: str,
+        object_type: FOLIONamespaces,
+        accept_duplicate_ids=False,
     ) -> tuple[dict, str]:
-
-        folio_object, legacy_id = self.instantiate_record(legacy_object, index_or_id, object_type)
+        folio_object, legacy_id = self.instantiate_record(
+            legacy_object, index_or_id, object_type, accept_duplicate_ids
+        )
         for property_name, property in self.schema["properties"].items():
             try:
                 self.map_property(property_name, property, folio_object, legacy_id, legacy_object)
@@ -258,7 +269,7 @@ class MappingFileMapperBase(MapperBase):
     ):
         if skip_property(schema_property_name, schema_property):
             pass
-        elif schema_property["type"] == "object":
+        elif schema_property.get("type", "") == "object":
             if "properties" in schema_property:
                 self.map_object_props(
                     legacy_object,
@@ -268,9 +279,9 @@ class MappingFileMapperBase(MapperBase):
                     index_or_id,
                     1,
                 )
-        elif schema_property["type"] == "array":
+        elif schema_property.get("type", "") == "array":
             try:
-                if schema_property["items"]["type"] == "object":
+                if schema_property["items"].get("type", "") == "object":
                     self.map_objects_array_props(
                         legacy_object,
                         schema_property_name,
@@ -279,7 +290,7 @@ class MappingFileMapperBase(MapperBase):
                         index_or_id,
                         schema_property["items"].get("required", []),
                     )
-                elif schema_property["items"]["type"] == "string":
+                elif schema_property["items"].get("type", "") == "string":
                     self.map_string_array_props(
                         legacy_object,
                         schema_property_name,
@@ -297,7 +308,32 @@ class MappingFileMapperBase(MapperBase):
                 )
 
         else:  # Basic property
-            self.map_basic_props(legacy_object, schema_property_name, folio_object, index_or_id)
+            self.map_basic_props(
+                legacy_object, schema_property_name, folio_object, index_or_id, schema_property
+            )
+
+    def get_value_from_map(
+        self,
+        folio_prop_name: str,
+        legacy_object: dict,
+        index_or_id: str = "",
+    ):
+        legacy_item_keys = self.mapped_from_legacy_data.get(folio_prop_name, [])
+        map_entries = list(
+            MappingFileMapperBase.get_map_entries_by_folio_prop_name(
+                folio_prop_name, self.record_map["data"]
+            )
+        )
+        if folio_prop_name in self.mapped_from_values and len(legacy_item_keys) == 1:
+            return self.mapped_from_values.get(folio_prop_name, "")
+        if len(map_entries) > 1:
+            self.migration_report.add(Blurbs.Details, f"{legacy_item_keys} were concatenated")
+        return " ".join(
+            MappingFileMapperBase.get_legacy_value(
+                legacy_object, map_entry, self.migration_report, index_or_id
+            )
+            for map_entry in map_entries
+        ).strip()
 
     @staticmethod
     def get_legacy_value(
@@ -306,6 +342,8 @@ class MappingFileMapperBase(MapperBase):
         migration_report: MigrationReport,
         index_or_id: str = "",
     ):
+        if mapping_file_entry.get("value", ""):
+            return mapping_file_entry.get("value")
         value = legacy_object.get(mapping_file_entry["legacy_field"], "").strip()
         if value and mapping_file_entry.get("rules", {}).get("replaceValues", {}):
             if replaced_val := mapping_file_entry["rules"]["replaceValues"].get(value, ""):
@@ -375,7 +413,7 @@ class MappingFileMapperBase(MapperBase):
                     level + 1,
                 )
             elif (
-                child_property["type"] == "array"
+                child_property.get("type", "") == "array"
                 and child_property.get("items", {}).get("type", "") == "object"
                 and child_property.get("items", {}).get("properties", "")
             ):
@@ -388,7 +426,7 @@ class MappingFileMapperBase(MapperBase):
                     [],
                 )
             elif (
-                child_property["type"] == "array"
+                child_property.get("type", "") == "array"
                 and child_property.get("items", {}).get("type", "") == "string"
             ):
                 self.map_string_array_props(
@@ -397,9 +435,13 @@ class MappingFileMapperBase(MapperBase):
                     folio_object,
                     index_or_id,
                 )
+            elif child_property.get("type", "") == "string":
+                path = sub_prop_path.split("].")[-1]
+                if p := self.get_prop(legacy_object, sub_prop_path, index_or_id):
+                    set_deep(folio_object, f"{path}", p)
+                # temp_object[child_property_name] = p
             elif p := self.get_prop(legacy_object, sub_prop_path, index_or_id):
                 set_deep(folio_object, sub_prop_path, p)
-                # temp_object[child_property_name] = p
         if temp_object:
             set_deep(folio_object, schema_property_name, temp_object)
             # folio_object[schema_property_name] = temp_object
@@ -424,52 +466,69 @@ class MappingFileMapperBase(MapperBase):
             for _ in keys_to_map:
                 temp_object = {}
                 multi_field_props: List[str] = []
-                for prop in (
-                    k for k, p in sub_properties.items() if not p.get("folio:isVirtual", False)
+                for sub_prop_name, sub_prop in (
+                    (k, p)
+                    for k, p in sub_properties.items()
+                    if not p.get("folio:isVirtual", False)
                 ):
-                    prop_path = f"{prop_name}[{i}].{prop}"
+                    prop_path = f"{prop_name}[{i}].{sub_prop_name}"
                     if prop_path in self.folio_keys:
                         # We have reached the end of the prop path?
                         res = self.get_prop(legacy_object, prop_path, index_or_id)
-                        self.report_legacy_mapping(self.legacy_basic_property(prop), True, True)
+                        self.report_legacy_mapping(
+                            self.legacy_basic_property(sub_prop_name), True, True
+                        )
 
                         if (
                             isinstance(res, str)
                             and self.library_configuration.multi_field_delimiter in res
                         ):
-                            multi_field_props.append(prop)
-                        temp_object[prop] = res
+                            multi_field_props.append(sub_prop_name)
+
+                        self.validate_enums(res, sub_prop, sub_prop_name, index_or_id, required)
+                        if res or isinstance(res, bool):
+                            temp_object[sub_prop_name] = res
 
                     elif (
-                        prop in sub_properties
-                        and sub_properties[prop].get("type", "") == "array"
-                        and sub_properties[prop]["items"].get("type", "") == "object"
+                        sub_prop_name in sub_properties
+                        and sub_properties[sub_prop_name].get("type", "") == "array"
+                        and sub_properties[sub_prop_name]["items"].get("type", "") == "object"
                     ):
                         self.map_objects_array_props(
                             legacy_object,
                             prop_path,
-                            sub_properties[prop]["items"]["properties"],
+                            sub_properties[sub_prop_name]["items"]["properties"],
                             folio_object,
                             index_or_id,
                             [],
                         )
                     elif (
-                        prop in sub_properties
-                        and sub_properties[prop].get("type", "") == "array"
-                        and sub_properties[prop]["items"].get("type", "") == "string"
+                        sub_prop_name in sub_properties
+                        and sub_properties[sub_prop_name].get("type", "") == "array"
+                        and sub_properties[sub_prop_name]["items"].get("type", "") == "string"
                     ):
                         # We have not reached the end of the prop path
                         for array_path in [p for p in self.folio_keys if p.startswith(prop_path)]:
                             res = self.get_prop(legacy_object, array_path, index_or_id)
-                            self.add_values_to_string_array(
-                                prop,
-                                temp_object,
-                                res,
-                                self.library_configuration.multi_field_delimiter,
+                            self.validate_enums(
+                                res, sub_prop, sub_prop_name, index_or_id, required
                             )
+                            if res or isinstance(res, bool):
+                                self.add_values_to_string_array(
+                                    sub_prop_name,
+                                    temp_object,
+                                    res,
+                                    self.library_configuration.multi_field_delimiter,
+                                )
+
+                    elif sub_prop.get("type", "") == "object" and "properties" in sub_prop:
+                        self.map_object_props(
+                            legacy_object, prop_path, sub_prop, temp_object, index_or_id, 0
+                        )
             i = i + 1
+
             if temp_object != {} and all(
-                (v or (isinstance(v, bool)) for k, v in temp_object.items() if k in required)
+                temp_object.get(r) or (isinstance(temp_object.get(r), bool)) for r in required
             ):
                 if any(multi_field_props):
                     resulting_array.extend(
@@ -481,6 +540,25 @@ class MappingFileMapperBase(MapperBase):
                     )
                 else:
                     resulting_array.append(temp_object)
+
+            elif any(
+                (
+                    v
+                    for k, v in temp_object.items()
+                    if not self.is_uuid(v) and not isinstance(v, bool)
+                )
+            ):
+                self.migration_report.add(
+                    Blurbs.IncompleteSubPropertyRemoved,
+                    f"{prop_name}",
+                )
+                # Helper.log_data_issue(
+                #     f"{prop_name}",
+                #     f"Sub-property {sub_prop} removed as it is missing required fields:"
+                #     f"{required}",
+                #     temp_object,
+                # )
+
         if any(resulting_array):
             set_deep2(folio_object, prop_name, resulting_array)
 
@@ -533,11 +611,26 @@ class MappingFileMapperBase(MapperBase):
             # No values in array previously
             set_deep(folio_object, prop, [mapped_prop_value])
 
-    def map_basic_props(self, legacy_object, prop, folio_object, index_or_id):
-        if self.has_basic_property(legacy_object, prop):  # is there a match in the csv?
-            if mapped_prop := self.get_prop(legacy_object, prop, index_or_id):
-                folio_object[prop] = mapped_prop
-            self.report_legacy_mapping(self.legacy_basic_property(prop), True, True)
+    def map_basic_props(
+        self, legacy_object, property_name, folio_object, index_or_id, schema_property
+    ):
+        if self.has_basic_property(legacy_object, property_name):  # is there a match in the csv?
+            if mapped_prop := self.get_prop(legacy_object, property_name, index_or_id):
+                self.validate_enums(
+                    mapped_prop,
+                    schema_property,
+                    property_name,
+                    index_or_id,
+                    self.schema.get("required", []),
+                )
+                folio_object[property_name] = mapped_prop
+            self.report_legacy_mapping(self.legacy_basic_property(property_name), True, True)
+        elif "default" in schema_property:
+            folio_object[property_name] = schema_property["default"]
+            self.migration_report.add(
+                Blurbs.DefaultValuesAdded,
+                f"From Schema: {property_name} -> {schema_property['default']}",
+            )
 
     @staticmethod
     def _get_delimited_file_reader(source_file, file_name: Path):
@@ -589,9 +682,6 @@ class MappingFileMapperBase(MapperBase):
             raise exception from exception
 
     def has_property(self, legacy_object, folio_prop_name: str):
-        if not self.use_map:
-            return folio_prop_name in legacy_object
-
         legacy_keys = self.field_map.get(folio_prop_name, [])
         return (
             any(legacy_keys)
@@ -600,9 +690,6 @@ class MappingFileMapperBase(MapperBase):
         )
 
     def has_basic_property(self, legacy_object, folio_prop_name):
-        if not self.use_map:
-            return folio_prop_name in legacy_object
-
         if folio_prop_name not in self.folio_keys:
             return False
         if folio_prop_name in self.mapped_from_values:
@@ -628,8 +715,6 @@ class MappingFileMapperBase(MapperBase):
         )
 
     def legacy_basic_property(self, folio_prop):
-        if not self.use_map:
-            return folio_prop
         if folio_prop not in self.folio_keys:
             return ""
         return next(
@@ -667,6 +752,54 @@ class MappingFileMapperBase(MapperBase):
         self.ref_data_dicts[dict_key] = d
         return self.ref_data_dicts.get(dict_key, {}).get(key_value.lower().strip(), ())
 
+    def validate_enums(
+        self,
+        mapped_value,
+        mapped_schema_property,
+        mapped_schema_property_name,
+        index_or_id,
+        required,
+    ):
+        if (
+            (
+                "enum" in mapped_schema_property
+                and mapped_value
+                and mapped_value not in mapped_schema_property["enum"]
+            )
+            or (
+                "enum" in mapped_schema_property
+                and mapped_schema_property_name in required
+                and not mapped_value
+            )
+            or (
+                mapped_schema_property.get("items", {}).get("enum")
+                and mapped_value
+                and mapped_value not in mapped_schema_property.get("items", {}).get("enum")
+            )
+        ):
+            raise TransformationRecordFailedError(
+                index_or_id,
+                f"Allowed values for {mapped_schema_property_name}"
+                f"are {mapped_schema_property['enum']} "
+                f"Forbidden enum value found: ",
+                mapped_value,
+            )
+
+    def is_uuid(self, value):
+        """Returns True if the value is a UUID, and False if it is not.
+
+        Args:
+            value (_type_): a value that may or may not be a UUID
+
+        Returns:
+            bool: True/False
+        """
+        try:
+            uuid.UUID(str(value))
+        except ValueError:
+            return False
+        return True
+
 
 def skip_property(property_name, property):
     return bool(
