@@ -22,7 +22,7 @@ class NotesMapper(MappingFileMappingBaseImpl):
         object_type: FOLIONamespaces,
         ignore_legacy_identifier: bool = False,
     ) -> None:
-        self.folio_client = folio_client
+        self.folio_client: FolioClient = folio_client
         self.setup_notes_schema()
         super().__init__(
             library_configuration,
@@ -47,7 +47,6 @@ class NotesMapper(MappingFileMappingBaseImpl):
 
     def map_notes(self, legacy_object, legacy_id, object_uuid: str, record_type: FOLIONamespaces):
         if any(self.noteprops["data"]):
-
             for note in self.do_map(legacy_object, legacy_id, FOLIONamespaces.note)[0].get(
                 "notes", []
             ):
@@ -55,11 +54,13 @@ class NotesMapper(MappingFileMappingBaseImpl):
                     type_string = {
                         FOLIONamespaces.users: "user",
                         FOLIONamespaces.course: "course",
+                        FOLIONamespaces.organizations: "organization",
                     }.get(record_type)
                     note["links"] = [{"id": object_uuid, "type": type_string}]
                     if "type" in note:
                         del note["type"]
                     self.extradata_writer.write("notes", note)
+                    self.migration_report.add_general_statistics("Number of linked notes created")
                     self.migration_report.add(Blurbs.MappedNoteTypes, note["typeId"])
                 else:
                     self.migration_report.add_general_statistics(
@@ -85,14 +86,13 @@ class NotesMapper(MappingFileMappingBaseImpl):
             for map_entry in map_entries
         ).strip()
 
-    @staticmethod
-    def get_notes_schema():
-        notes_schema = FolioClient.get_latest_from_github(
+    def get_notes_schema(self):
+        notes_schema = self.folio_client.get_from_github(
             "folio-org",
             "mod-notes",
             "src/main/resources/swagger.api/schemas/note.yaml",
         )
-        notes_common = FolioClient.get_latest_from_github(
+        notes_common = self.folio_client.get_from_github(
             "folio-org",
             "mod-notes",
             "src/main/resources/swagger.api/schemas/common.yaml",
