@@ -13,6 +13,7 @@ from folio_migration_tools.library_configuration import LibraryConfiguration
 from folio_migration_tools.mapping_file_transformation.mapping_file_mapper_base import (
     MappingFileMapperBase,
 )
+from folio_migration_tools.mapping_file_transformation.notes_mapper import NotesMapper
 from folio_migration_tools.mapping_file_transformation.ref_data_mapping import (
     RefDataMapping,
 )
@@ -30,8 +31,9 @@ class OrganizationMapper(MappingFileMapperBase):
         email_categories_map,
         phone_categories_map,
     ):
-
         # Build composite organization schema
+        if os.environ.get("GITHUB_TOKEN"):
+            logging.info("Using GITHB_TOKEN environment variable for Gihub API Access")
         organization_schema = OrganizationMapper.get_latest_acq_schemas_from_github(
             "folio-org", "mod-organizations-storage", "mod-orgs", "organization"
         )
@@ -44,9 +46,7 @@ class OrganizationMapper(MappingFileMapperBase):
             FOLIONamespaces.organizations,
             library_configuration,
         )
-
-        self.use_map = True
-
+        self.organization_schema = organization_schema
         # Set up reference data maps
         self.set_up_reference_data_mapping(
             organization_types_map,
@@ -55,6 +55,16 @@ class OrganizationMapper(MappingFileMapperBase):
             phone_categories_map,
         )
 
+        self.folio_client: FolioClient = folio_client
+        self.notes_mapper: NotesMapper = NotesMapper(
+            library_configuration,
+            self.folio_client,
+            organization_map,
+            FOLIONamespaces.note,
+            True,
+        )
+        self.notes_mapper.migration_report = self.migration_report
+
     # Commence the mapping work
     def get_prop(self, legacy_organization, folio_prop_name, index_or_id):
         value_tuple = (
@@ -63,21 +73,10 @@ class OrganizationMapper(MappingFileMapperBase):
             folio_prop_name,
         )
 
-        if not self.use_map:
-            return legacy_organization[folio_prop_name]
-
-        legacy_organization_keys = self.mapped_from_legacy_data.get(folio_prop_name, [])
-
-        # If there is a verbatim "value" set in the object map, return that one
-        if len(legacy_organization_keys) == 1 and folio_prop_name in self.mapped_from_values:
-            value = self.mapped_from_values.get(folio_prop_name, "")
-            self.migration_report.add(
-                Blurbs.DefaultValuesAdded, f"{value} added to {folio_prop_name}"
-            )
-            return value
+        mapped_value = self.get_value_from_map(folio_prop_name, legacy_organization, index_or_id)
 
         # Perfrom reference data mappings
-        elif folio_prop_name == "organizationTypes":
+        if folio_prop_name == "organizationTypes":
             return self.get_mapped_value(
                 self.organization_types_map,
                 *value_tuple,
@@ -105,17 +104,12 @@ class OrganizationMapper(MappingFileMapperBase):
                 False,
             )
 
-        legacy_values = MappingFileMapperBase.get_legacy_vals(
-            legacy_organization, legacy_organization_keys
-        )
-        legacy_value = " ".join(legacy_values).strip()
+        elif re.compile("interfaces\[(\d+)\]\.interfaceCredential.interfaceId").fullmatch(
+            folio_prop_name
+        ):
+            return "replace_with_interface_id"
 
-        # What dores the below do?
-        if any(legacy_organization_keys):
-            return legacy_value
-        else:
-            # edge case
-            return ""
+        return mapped_value
 
     def set_up_reference_data_mapping(
         self,
@@ -189,7 +183,6 @@ class OrganizationMapper(MappingFileMapperBase):
             _type_: _description_
         """
         try:
-
             # Authenticate when calling GitHub, using an API key stored in .env
             github_headers = {
                 "content-type": "application/json",
@@ -197,7 +190,6 @@ class OrganizationMapper(MappingFileMapperBase):
             }
 
             if os.environ.get("GITHUB_TOKEN"):
-                logging.info("Using GITHB_TOKEN environment variable for Gihub API Access")
                 github_headers["authorization"] = f"token {os.environ.get('GITHUB_TOKEN')}"
 
             # Start talkign to GitHub...
@@ -304,9 +296,7 @@ class OrganizationMapper(MappingFileMapperBase):
         supported_types = ["string", "boolean", "number", "integer", "text", "object", "array"]
 
         try:
-
             for property_name_level1, property_level1 in object_schema["properties"].items():
-
                 # For now, treat references to UUIDs like strings
                 # It's not great practice, but it's the way FOLIO mostly handles it
                 if "../../common/schemas/uuid.json" in property_level1.get("$ref", ""):
@@ -327,7 +317,23 @@ class OrganizationMapper(MappingFileMapperBase):
                     contact_schema = OrganizationMapper.fetch_additional_schema("contact")
                     property_level1["items"] = contact_schema
 
-                    logging.info(f"{property_name_level1} will be handled separately.")
+                elif property_name_level1 == "interfaces":
+                    interface_schema = OrganizationMapper.fetch_additional_schema("interface")
+                    interface_schema["required"] = ["name"]
+
+                    # Temporarily add the credential object as a subproperty
+                    interface_credential_schema = OrganizationMapper.fetch_additional_schema(
+                        "interface_credential"
+                    )
+                    interface_credential_schema["required"] = (
+                        ["username", "password", "interfaceId"],
+                    )
+
+                    interface_schema["properties"][
+                        "interfaceCredential"
+                    ] = interface_credential_schema
+
+                    property_level1["items"] = interface_schema
 
                 elif (
                     property_level1.get("type") == "array"
@@ -342,13 +348,10 @@ class OrganizationMapper(MappingFileMapperBase):
                     or "../" in property_level1.get("$ref", "")
                     or "../" in property_level1.get("items", {}).get("$ref", "")
                 ):
-
                     logging.info(f"Property not yet supported: {property_name_level1}")
-                    property_level1["type"] = "Deprecated"
 
                 # Handle object properties
                 elif property_level1.get("type") == "object" and property_level1.get("$ref"):
-
                     logging.info("Fecthing referenced schema for object %s", property_name_level1)
 
                     ref_object = property_level1["$ref"]
@@ -362,7 +365,6 @@ class OrganizationMapper(MappingFileMapperBase):
                 elif property_level1.get("type") == "array" and property_level1.get("items").get(
                     "$ref"
                 ):
-
                     ref_object = property_level1["items"]["$ref"]
                     schema_url = f"{submodule_path}/{ref_object}"
 
